/*
 * Copyright 2025 ES4X
 *
 * ES4X licenses this file to you under the Apache License, version 2.0
 * (the "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

/**
 * Options for configuring the {@link ApolloWSHandler}.
 */
export class ApolloWSOptions {

  constructor();

  constructor(obj: ApolloWSOptions | { [key: string]: any });

  /**
   * Set the interval in milliseconds to send <code>KEEPALIVE</code> messages to all clients. Defaults to <code>30000</code>.
   */
  getKeepAlive(): number;

  /**
   * Set the interval in milliseconds to send <code>KEEPALIVE</code> messages to all clients. Defaults to <code>30000</code>.
   */
  setKeepAlive(keepAlive: number): ApolloWSOptions;

  /**
   * Set the <code>Origin</code> for this handler, by default it will be <code>null</code>.
   */
  getOrigin(): string;

  /**
   * Set the <code>Origin</code> for this handler, by default it will be <code>null</code>.
   */
  setOrigin(origin: string): ApolloWSOptions;


  toJson(): { [key: string]: any };
}

/**
 * Options for configuring the {@link GraphQLHandler}.
 */
export class GraphQLHandlerOptions {

  constructor();

  constructor(obj: GraphQLHandlerOptions | { [key: string]: any });

  /**
   * Whether request batching should be enabled. Defaults to <code>false</code>.
   */
  isRequestBatchingEnabled(): boolean;

  /**
   * Whether request batching should be enabled. Defaults to <code>false</code>.
   */
  setRequestBatchingEnabled(requestBatchingEnabled: boolean): GraphQLHandlerOptions;

  /**
   * Whether request multipart should be enabled. Defaults to <code>false</code>.
   */
  isRequestMultipartEnabled(): boolean;

  /**
   * Whether request multipart should be enabled. Defaults to <code>false</code>.
   */
  setRequestMultipartEnabled(requestMultipartEnabled: boolean): GraphQLHandlerOptions;


  toJson(): { [key: string]: any };
}

/**
 * Options for configuring the {@link GraphQLWSHandler}.
 */
export class GraphQLWSOptions {

  constructor();

  constructor(obj: GraphQLWSOptions | { [key: string]: any });

  /**
   * Set the maximum delay in milliseconds for the client to send the <code>CONNECTION_INIT</code> message.
   * Defaults to <code>3000</code>.
   */
  getConnectionInitWaitTimeout(): number;

  /**
   * Set the maximum delay in milliseconds for the client to send the <code>CONNECTION_INIT</code> message.
   * Defaults to <code>3000</code>.
   */
  setConnectionInitWaitTimeout(connectionInitWaitTimeout: number): GraphQLWSOptions;


  toJson(): { [key: string]: any };
}

/**
 * Embedded GraphiQL user interface options.
 */
export class GraphiQLHandlerOptions {

  constructor();

  constructor(obj: GraphiQLHandlerOptions | { [key: string]: any });

  /**
   * Whether the GraphiQL development tool should be enabled. Defaults to <code>false</code>.
   */
  isEnabled(): boolean;

  /**
   * Whether the GraphiQL development tool should be enabled. Defaults to <code>false</code>.
   */
  setEnabled(enabled: boolean): GraphiQLHandlerOptions;

  /**
   * Set the GraphQL HTTP endpoint URI. Defaults to <a href="../../dataobjects.html#GraphiQLHandlerOptions">GraphiQLHandlerOptions</a>.
   */
  getGraphQLUri(): string;

  /**
   * Set the GraphQL HTTP endpoint URI. Defaults to <a href="../../dataobjects.html#GraphiQLHandlerOptions">GraphiQLHandlerOptions</a>.
   */
  setGraphQLUri(graphQLUri: string): GraphiQLHandlerOptions;

  /**
   * Whether the GraphQLWS transport should be enabled. Defaults to <code>true</code>.
   */
  isGraphQLWSEnabled(): boolean;

  /**
   * Whether the GraphQLWS transport should be enabled. Defaults to <code>true</code>.
   */
  setGraphQLWSEnabled(graphQLWSEnabled: boolean): GraphiQLHandlerOptions;

  /**
   */
  getGraphQLWSUri(): string;

  /**
   * Set the GraphQLWS endpoint URI. Defaults to <a href="../../dataobjects.html#GraphiQLHandlerOptions">GraphiQLHandlerOptions</a>.
   */
  setGraphWSQLUri(graphWSQLUri: string): GraphiQLHandlerOptions;

  /**
   * A fixed set of HTTP headers to add to GraphiQL requests. Defaults to <code>null</code>.
   */
  getHeaders(): { [key: string]: string };

  /**
   * A fixed set of HTTP headers to add to GraphiQL requests. Defaults to <code>null</code>.
   */
  setHeaders(headers: { [key: string]: string }): GraphiQLHandlerOptions;

  /**
   * Whether the HTTP transport should be enabled. Defaults to <code>true</code>.
   */
  isHttpEnabled(): boolean;

  /**
   * Whether the HTTP transport should be enabled. Defaults to <code>true</code>.
   */
  setHttpEnabled(httpEnabled: boolean): GraphiQLHandlerOptions;

  /**
   * Initial value of the query area in the GraphiQL user interface. Defaults to <code>null</code>.
   */
  getQuery(): string;

  /**
   * Initial value of the query area in the GraphiQL user interface. Defaults to <code>null</code>.
   */
  setQuery(query: string): GraphiQLHandlerOptions;

  /**
   * Initial value of the variables area in the GraphiQL user interface. Defaults to <code>null</code>.
   */
  getVariables(): { [key: string]: any };

  /**
   * Initial value of the variables area in the GraphiQL user interface. Defaults to <code>null</code>.
   */
  setVariables(variables: { [key: string]: any }): GraphiQLHandlerOptions;

  /**
   * Initial GraphQLWS connection params. Defaults to <code>null</code>.
   */
  getWsConnectionParams(): { [key: string]: any };

  /**
   * Initial GraphQLWS connection params. Defaults to <code>null</code>.
   */
  setWsConnectionParams(wsConnectionParams: { [key: string]: any }): GraphiQLHandlerOptions;


  toJson(): { [key: string]: any };
}
